@@ -22,9 +22,10 @@
 #ifndef EXTRACTHEREDNDPLUGIN_H
 #define EXTRACTHEREDNDPLUGIN_H
 
-#include <qurl.h>
 #include <KIO/DndPopupMenuPlugin>
 
+#include <QUrl>
+
 class ExtractHereDndPlugin : public KIO::DndPopupMenuPlugin
 {
     Q_OBJECT
@@ -35,8 +36,8 @@ private slots:
 public:
     ExtractHereDndPlugin(QObject* parent, const QVariantList&);
 
-    virtual QList<QAction *> setup(const KFileItemListProperties& popupMenuInfo,
-                                   const QUrl& destination) Q_DECL_OVERRIDE;
+    QList<QAction *> setup(const KFileItemListProperties& popupMenuInfo,
+                                   const QUrl& destination) override;
 
 private:
     QUrl m_dest;
