@@ -55,8 +55,8 @@ class KERFUFFLE_EXPORT AddToArchive : public KJob
     Q_OBJECT
 
 public:
-    explicit AddToArchive(QObject *parent = 0);
-    ~AddToArchive();
+    explicit AddToArchive(QObject *parent = nullptr);
+    ~AddToArchive() override;
 
     bool showAddDialog();
     void setPreservePaths(bool value);
@@ -70,10 +70,10 @@ public slots:
     void setMimeType(const QString & mimeType);
     void setPassword(const QString &password);
     void setHeaderEncryptionEnabled(bool enabled);
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 protected:
-    bool doKill() Q_DECL_OVERRIDE;
+    bool doKill() override;
 
 private slots:
     void slotFinished(KJob*);
