@@ -52,8 +52,6 @@ class KERFUFFLE_EXPORT CliInterface : public ReadWriteArchiveInterface
     Q_OBJECT
 
 public:
-    OperationMode m_operationMode = List;
-
     explicit CliInterface(QObject *parent, const QVariantList & args);
     ~CliInterface() override;
 
@@ -136,8 +134,10 @@ protected:
 
     void cleanUp();
 
+    OperationMode m_operationMode = List;
     CliProperties *m_cliProps = nullptr;
-    QString m_oldWorkingDir;
+    QString m_oldWorkingDirExtraction; // Used ONLY by extraction jobs.
+    QString m_oldWorkingDir; // Used by copy and move jobs.
     QScopedPointer<QTemporaryDir> m_tempWorkingDir;
     QScopedPointer<QTemporaryDir> m_tempAddDir;
     OperationMode m_subOperation = List;
@@ -195,6 +195,7 @@ private:
     virtual QString escapeFileName(const QString &fileName) const;
 
     void cleanUpExtracting();
+    void restoreWorkingDirExtraction();
 
     void finishCopying(bool result);
 
