@@ -29,16 +29,16 @@
 #define EXTRACTIONSETTINGSPAGE_H
 
 #include "settingspage.h"
-#include "ui_extractionsettings.h"
+#include "ui_extractionsettingspage.h"
 
 namespace Kerfuffle
 {
-class KERFUFFLE_EXPORT ExtractionSettingsPage : public SettingsPage, public Ui::ExtractionSettings
+class KERFUFFLE_EXPORT ExtractionSettingsPage : public SettingsPage, public Ui::ExtractionSettingsPage
 {
     Q_OBJECT
 
 public:
-    explicit ExtractionSettingsPage(QWidget *parent = 0, const QString &name = QString(), const QString &iconName = QString());
+    explicit ExtractionSettingsPage(QWidget *parent = nullptr, const QString &name = QString(), const QString &iconName = QString());
 };
 }
 
