@@ -22,10 +22,10 @@
 #ifndef JOBTRACKER_H
 #define JOBTRACKER_H
 
-#include <QFrame>
-#include <kabstractwidgetjobtracker.h>
 #include "ui_jobtracker.h"
 
+#include <KAbstractWidgetJobTracker>
+
 class KJob;
 
 class JobTrackerWidget: public QFrame, public Ui::JobTrackerWidget
@@ -33,7 +33,7 @@ class JobTrackerWidget: public QFrame, public Ui::JobTrackerWidget
     Q_OBJECT
 
 public:
-    explicit JobTrackerWidget(QWidget *parent = 0);
+    explicit JobTrackerWidget(QWidget *parent = nullptr);
 };
 
 class JobTracker: public KAbstractWidgetJobTracker
@@ -41,21 +41,21 @@ class JobTracker: public KAbstractWidgetJobTracker
     Q_OBJECT
 
 public:
-    explicit JobTracker(QWidget *parent = 0);
-    ~JobTracker();
+    explicit JobTracker(QWidget *parent = nullptr);
+    ~JobTracker() override;
 
-    QWidget *widget(KJob *) Q_DECL_OVERRIDE;
+    QWidget *widget(KJob *) override;
 
 public slots:
-    void registerJob(KJob *job) Q_DECL_OVERRIDE;
-    void unregisterJob(KJob *job) Q_DECL_OVERRIDE;
+    void registerJob(KJob *job) override;
+    void unregisterJob(KJob *job) override;
 
 protected slots:
-    void description(KJob *job, const QString &title, const QPair< QString, QString > &f1, const QPair< QString, QString > &f2)  Q_DECL_OVERRIDE;
-    void infoMessage(KJob *job, const QString &plain, const QString &rich) Q_DECL_OVERRIDE;
-    void warning(KJob *job, const QString &plain, const QString &rich) Q_DECL_OVERRIDE;
+    void description(KJob *job, const QString &title, const QPair< QString, QString > &f1, const QPair< QString, QString > &f2)  override;
+    void infoMessage(KJob *job, const QString &plain, const QString &rich) override;
+    void warning(KJob *job, const QString &plain, const QString &rich) override;
 
-    void percent(KJob *job, unsigned long  percent) Q_DECL_OVERRIDE;
+    void percent(KJob *job, unsigned long  percent) override;
 
 private slots:
     void resetUi();
