@@ -46,6 +46,9 @@ LibarchivePlugin::LibarchivePlugin(QObject *parent, const QVariantList &args)
 {
     qCDebug(ARK) << "Initializing libarchive plugin";
     archive_read_disk_set_standard_lookup(m_archiveReadDisk.data());
+
+    connect(this, &ReadOnlyArchiveInterface::error, this, &LibarchivePlugin::slotRestoreWorkingDir);
+    connect(this, &ReadOnlyArchiveInterface::cancelled, this, &LibarchivePlugin::slotRestoreWorkingDir);
 }
 
 LibarchivePlugin::~LibarchivePlugin()
@@ -160,19 +163,6 @@ bool LibarchivePlugin::doKill()
 
 bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const QString &destinationDirectory, const ExtractionOptions &options)
 {
-    qCDebug(ARK) << "Changing current directory to " << destinationDirectory;
-    QDir::setCurrent(destinationDirectory);
-
-    const bool extractAll = files.isEmpty();
-    const bool preservePaths = options.preservePaths();
-    const bool removeRootNode = options.isDragAndDropEnabled();
-
-    // To avoid traversing the entire archive when extracting a limited set of
-    // entries, we maintain a list of remaining entries and stop when it's
-    // empty.
-    QStringList fullPaths = entryFullPaths(files);
-    QStringList remainingFiles = entryFullPaths(files);
-
     if (!initializeReader()) {
         return false;
     }
@@ -184,9 +174,8 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const
 
     archive_write_disk_set_options(writer.data(), extractionFlags());
 
-    int entryNr = 0;
-    int totalCount = 0;
-
+    int totalEntriesCount = 0;
+    const bool extractAll = files.isEmpty();
     if (extractAll) {
         if (!m_cachedArchiveEntryCount) {
             emit progress(0);
@@ -197,23 +186,32 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const
             list();
             m_emitNoEntries = false;
         }
-        totalCount = m_cachedArchiveEntryCount;
+        totalEntriesCount = m_cachedArchiveEntryCount;
     } else {
-        totalCount = files.size();
+        totalEntriesCount = files.size();
     }
 
-    qCDebug(ARK) << "Going to extract" << totalCount << "entries";
+    qCDebug(ARK) << "Going to extract" << totalEntriesCount << "entries";
 
+    qCDebug(ARK) << "Changing current directory to " << destinationDirectory;
+    m_oldWorkingDir = QDir::currentPath();
+    QDir::setCurrent(destinationDirectory);
 
     // Initialize variables.
+    const bool preservePaths = options.preservePaths();
+    const bool removeRootNode = options.isDragAndDropEnabled();
     bool overwriteAll = false; // Whether to overwrite all files
     bool skipAll = false; // Whether to skip all files
     bool dontPromptErrors = false; // Whether to prompt for errors
     m_currentExtractedFilesSize = 0;
-    int no_entries = 0;
-
+    int extractedEntriesCount = 0;
+    int progressEntryCount = 0;
     struct archive_entry *entry;
     QString fileBeingRenamed;
+    // To avoid traversing the entire archive when extracting a limited set of
+    // entries, we maintain a list of remaining entries and stop when it's empty.
+    const QStringList fullPaths = entryFullPaths(files);
+    QStringList remainingFiles = entryFullPaths(files);
 
     // Iterate through all entries in archive.
     while (!QThread::currentThread()->isInterruptionRequested() && (archive_read_next_header(m_archiveReader.data(), &entry) == ARCHIVE_OK)) {
@@ -228,9 +226,7 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const
         // Retry with renamed entry, fire an overwrite query again
         // if the new entry also exists.
     retry:
-
         const bool entryIsDir = S_ISDIR(archive_entry_mode(entry));
-
         // Skip directories if not preserving paths.
         if (!preservePaths && entryIsDir) {
             archive_read_data_skip(m_archiveReader.data());
@@ -280,14 +276,12 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const
             //qCDebug(ARK) << "setting path to " << archive_entry_pathname( entry );
 
             const QString fileWithoutPath(entryFI.fileName());
-
             // If we DON'T preserve paths, we cut the path and set the entryFI
             // fileinfo to the one without the path.
             if (!preservePaths) {
                 // Empty filenames (ie dirs) should have been skipped already,
                 // so asserting.
                 Q_ASSERT(!fileWithoutPath.isEmpty());
-
                 archive_entry_copy_pathname(entry, QFile::encodeName(fileWithoutPath).constData());
                 entryFI = QFileInfo(fileWithoutPath);
 
@@ -296,7 +290,6 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const
                 const QString &rootNode = files.at(index)->rootNode;
                 if (!rootNode.isEmpty()) {
                     const QString truncatedFilename(entryName.remove(entryName.indexOf(rootNode), rootNode.size()));
-
                     archive_entry_copy_pathname(entry, QFile::encodeName(truncatedFilename).constData());
                     entryFI = QFileInfo(truncatedFilename);
                 }
@@ -366,7 +359,6 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const
                 // If they user previously decided to ignore future errors,
                 // don't bother prompting again.
                 if (!dontPromptErrors) {
-
                     // Ask the user if he wants to continue extraction despite an error for this entry.
                     Kerfuffle::ContinueExtractionQuery query(QLatin1String(archive_error_string(writer.data())),
                                                              entryName);
@@ -396,24 +388,20 @@ bool LibarchivePlugin::extractFiles(const QVector<Archive::Entry*> &files, const
             // archive entries is available we use a simple progress based on
             // number of items extracted.
             if (!extractAll && m_cachedArchiveEntryCount) {
-                ++entryNr;
-                emit progress(float(entryNr) / totalCount);
+                ++progressEntryCount;
+                emit progress(float(progressEntryCount) / totalEntriesCount);
             }
-            no_entries++;
 
+            extractedEntriesCount++;
             remainingFiles.removeOne(entryName);
-
         } else {
-
             // Archive entry not among selected files, skip it.
             archive_read_data_skip(m_archiveReader.data());
-
         }
+    }
 
-    } // While entries left to read in archive.
-
-    qCDebug(ARK) << "Extracted" << no_entries << "entries";
-
+    qCDebug(ARK) << "Extracted" << extractedEntriesCount << "entries";
+    slotRestoreWorkingDir();
     return archive_read_close(m_archiveReader.data()) == ARCHIVE_OK;
 }
 
@@ -548,6 +536,19 @@ void LibarchivePlugin::copyData(const QString& filename, struct archive *source,
     }
 }
 
+void LibarchivePlugin::slotRestoreWorkingDir()
+{
+    if (m_oldWorkingDir.isEmpty()) {
+        return;
+    }
+
+    if (!QDir::setCurrent(m_oldWorkingDir)) {
+        qCWarning(ARK) << "Failed to restore old working directory:" << m_oldWorkingDir;
+    } else {
+        m_oldWorkingDir.clear();
+    }
+}
+
 QString LibarchivePlugin::convertCompressionName(const QString &method)
 {
     if (method == QLatin1String("gzip")) {
